<?php

namespace App\Http\Controllers;

use App\Download;
use App\Http\Requests\CreateDownloadFormRequest;
use Illuminate\Http\Request;

class DownloadController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        //
        $dl_files=Download::orderBy('created_at','desc')->paginate(5);
        return view('dashboard.downloads')->with('dlfiles', $dl_files);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
        return view('dashboard.downloads.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(CreateDownloadFormRequest $request)
    {
        //
        $download = new Download();
        $download-> dl_name = $request->get('downloadtitle');
        $download-> dl_show = $request->get('dlstatus');

        $file = $request->file('file');
        $file_name = time() . $file->getClientOriginalName();
        $file_path = 'uploads/downloads';
        $file->move($file_path, $file_name);
        $download -> dl_file_url = $file_path.'/'.$file_name;

        $download->save();

        return \Redirect::route('downloads.index')->with('message', 'New Download Added Successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Download  $download
     * @return \Illuminate\Http\Response
     */
    public function show(Download $download)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Download  $download
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
        $dlfileupdate = Download::find($id);
        return view('dashboard.downloads.edit',compact('dlfileupdate','dlfileupdate'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Download  $download
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
        $request->validate([
            'dltitle'=>'required',
            'dlstatus'=>'required'
        ]);

        $dlfileupdate = Download::find($id);
        $dlfileupdate->dl_name = $request->get('dltitle');
        $dlfileupdate->dl_show = $request->get('dlstatus');
        $dlfileupdate->save();

        return \Redirect::route('downloads.index')->with('message', 'Download Updated Successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Download  $download
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
        if(empty(Download::find($id))){
            return \redirect::route('downloads.index');
        }
        else{
            Download::destroy($id);
            return \Redirect::route('downloads.index')->with('message','Item Deleted Successfully');
        }
    }
}
